%undefine __cmake_in_source_build
Name:           assimp
Version:        5.0.1
Release:    2%{?dist}
Summary:        Library to import various 3D model formats into applications

License:        BSD and MIT and Boost and Unlicense and zlib
URL:            https://github.com/assimp/assimp

Source0:        %{name}-%{version}-free.tar.xz
Source1:        assimp_generate_tarball.sh

Patch0:         %{name}-5.0.1-unbundle.patch
Patch1:         %{name}-5.0.1-pythonpath.patch
Patch2:         %{name}-5.0.1-pkgconfig.patch
Patch3:         %{name}-5.0.1-doxyfile.patch
Patch4:         %{name}-5.0.1-irrxml.patch
Patch5:         %{name}-5.0.1-assimpversion.patch
Patch6:         %{name}-5.0.1-lib-dir.patch
Patch7:         %{name}-5.0.1-CVE-2024-40724.patch

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  doxygen
BuildRequires:  irrlicht-devel
BuildRequires:  irrXML-devel
BuildRequires:  gcc-c++
BuildRequires:  gtest-devel
BuildRequires:  make
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(python3)
BuildRequires:  poly2tri-devel
BuildRequires:  python3-devel
BuildRequires:  rapidjson-devel
BuildRequires:  rapidjson-static
%global min_stb_image 2.27^20210910gitaf1a5bc-0.2
BuildRequires:  stb_image-devel >= %{min_stb_image}
BuildRequires:  stb_image-static
BuildRequires:  utf8cpp-devel
BuildRequires:  utf8cpp-static

Provides: bundled(polyclipping) = 4.8.8
Provides: bundled(open3dgc)
Provides: bundled(openddl-parser)
Provides: bundled(unzip)
Provides: bundled(minzip)
Provides: bundled(zlib)

%description
Assimp, the Open Asset Import Library, is a free library to import
various well-known 3D model formats into applications.  Assimp aims
to provide a full asset conversion pipeline for use in game
engines and real-time rendering systems, but is not limited
to these applications.

%package devel
Summary: Header files and libraries for assimp
Requires: %{name} = %{version}-%{release}

%description devel
This package contains the header files and libraries
for assimp. If you would like to develop programs using assimp,
you will need to install assimp-devel.

%package -n python3-%{name}
Summary: Python 3 bindings for assimp
BuildArch: noarch
Requires: %{name} = %{version}-%{release}
Requires: python3
Provides: %{name}-python3 = %{version}-%{release}

%description -n python3-%{name}
This package contains the PyAssimp3 python bindings

%package doc
Summary: Assimp documentation
BuildArch: noarch

%description doc
%{summary}.

%prep
%setup -q
rm -r contrib/android-cmake
rm -r contrib/irrXML
rm -r contrib/poly2tri
rm -r contrib/rapidjson
rm -r contrib/stb_image
rm -r contrib/utf8cpp

%patch0 -p1 -b .unbundle
%patch1 -p1 -b .pythonpath
%patch2 -p1 -b .pkgconfig
%patch3 -p1 -b .doxyfile
%patch4 -p1 -b .irrxml
%patch5 -p1 -b .assimpversion
%patch6 -p1 -b .libdir
%patch7 -p1 -b .CVE-2024-40724

%build
%cmake \
 -DCMAKE_BUILD_TYPE=None \
 -DASSIMP_LIB_INSTALL_DIR=%{_lib} \
%ifarch s390x ppc64
 -DAI_BUILD_BIG_ENDIAN=TRUE \
%endif
 -DBUILD_DOCS=OFF \
 -DHTML_OUTPUT=%{name}-%{version} \
 -DCMAKE_INSTALL_DOCDIR=%{_docdir} \
 -DPOLY2TRI_INCLUDE_PATH=%{_includedir}/poly2tri \
 -DSYSTEM_IRRXML=ON \
 -DASSIMP_BUILD_ZLIB=ON

%cmake_build

dos2unix README LICENSE CREDITS port/PyAssimp/README.md
iconv -f iso8859-1 -t utf-8 CREDITS > CREDITS.conv && mv -f CREDITS.conv CREDITS

%install
%cmake_install
mkdir -p %{buildroot}%{python3_sitelib}/pyassimp/
install -m0644 port/PyAssimp/pyassimp/*.py %{buildroot}%{python3_sitelib}/pyassimp/
rm -f %{buildroot}%{_libdir}/libzlibstatic.a


%files
%license LICENSE 
%license contrib/clipper/License.txt
%license contrib/openddlparser/LICENSE
%license contrib/zip/UNLICENSE
%doc Readme.md CREDITS
%{_bindir}/assimp
%{_libdir}/*.so.*

%files devel
%{_includedir}/assimp
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/*

%files doc
%{_docdir}/*

%files -n python3-%{name}
%doc port/PyAssimp/README.md
%{python3_sitelib}/pyassimp

%changelog
* Tue Apr 01 2025 Fanjun Kong <fanjunkong@tencent.com> - 5.0.1-2
- fix CVE-2024-40724

* Thu Aug 08 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.0.1-1
- initial build
